linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Cyrill Gorcunov <gorcunov@gmail.com>
To: macro@linux-mips.org, mingo@elte.hu, tglx@linutronix.de
Cc: hpa@zytor.com, yhlu.kernel@gmail.com,
	linux-kernel@vger.kernel.org,
	Cyrill Gorcunov <gorcunov@gmail.com>
Subject: [patch 7/8] x86: apic - unify sync_Arb_IDs
Date: Thu, 01 Jan 1970 03:00:07 +0300	[thread overview]
Message-ID: <20080814184652.317090901@gmail.com> (raw)
In-Reply-To: 20080814183428.550709025@gmail.com

[-- Attachment #1: 0011-x86-apic-unify-sync_Arb_IDs.patch --]
[-- Type: text/plain, Size: 1387 bytes --]

Signed-off-by: Cyrill Gorcunov <gorcunov@gmail.com>
---

diff --git a/arch/x86/kernel/apic_32.c b/arch/x86/kernel/apic_32.c
index 1d5f830..ec0f18f 100644
--- a/arch/x86/kernel/apic_32.c
+++ b/arch/x86/kernel/apic_32.c
@@ -919,8 +919,7 @@ void __init sync_Arb_IDs(void)
 	apic_wait_icr_idle();
 
 	apic_printk(APIC_DEBUG, "Synchronizing Arb IDs.\n");
-	apic_write(APIC_ICR,
-		   APIC_DEST_ALLINC | APIC_INT_LEVELTRIG | APIC_DM_INIT);
+	apic_write(APIC_ICR, APIC_DEST_ALLINC | APIC_INT_LEVELTRIG | APIC_DM_INIT);
 }
 
 /*
diff --git a/arch/x86/kernel/apic_64.c b/arch/x86/kernel/apic_64.c
index 5d07689..f8d2918 100644
--- a/arch/x86/kernel/apic_64.c
+++ b/arch/x86/kernel/apic_64.c
@@ -746,8 +746,11 @@ int __init verify_local_APIC(void)
  */
 void __init sync_Arb_IDs(void)
 {
-	/* Unsupported on P4 - see Intel Dev. Manual Vol. 3, Ch. 8.6.1 */
-	if (modern_apic())
+	/*
+	 * Unsupported on P4 - see Intel Dev. Manual Vol. 3, Ch. 8.6.1 And not
+	 * needed on AMD.
+	 */
+	if (modern_apic() || boot_cpu_data.x86_vendor == X86_VENDOR_AMD)
 		return;
 
 	/*
@@ -756,8 +759,7 @@ void __init sync_Arb_IDs(void)
 	apic_wait_icr_idle();
 
 	apic_printk(APIC_DEBUG, "Synchronizing Arb IDs.\n");
-	apic_write(APIC_ICR, APIC_DEST_ALLINC | APIC_INT_LEVELTRIG
-				| APIC_DM_INIT);
+	apic_write(APIC_ICR, APIC_DEST_ALLINC | APIC_INT_LEVELTRIG | APIC_DM_INIT);
 }
 
 /*
-- 
1.6.0.rc1.34.g0fe8c

-- 

  parent reply	other threads:[~2008-08-14 18:49 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2008-08-14 18:34 [patch 0/8] [RFC -tip] another one step toward APIC merging Cyrill Gorcunov
1970-01-01  0:00 ` [patch 1/8] x86: apic - use SET_APIC_DEST_FIELD instead of hardcoded shift Cyrill Gorcunov
1970-01-01  0:00 ` [patch 2/8] x86: apic - unify disable_apic_timer Cyrill Gorcunov
1970-01-01  0:00 ` [patch 3/8] x86: apic - unify __setup_APIC_LVTT Cyrill Gorcunov
1970-01-01  0:00 ` [patch 4/8] x86: apic - do not clear APIC twice in lapic_shutdown Cyrill Gorcunov
1970-01-01  0:00 ` [patch 5/8] x86: apic - get rid of local_apic_timer_verify_ok Cyrill Gorcunov
1970-01-01  0:00 ` [patch 6/8] x86: apic - unify verify_local_APIC Cyrill Gorcunov
1970-01-01  0:00 ` Cyrill Gorcunov [this message]
2008-08-14 19:41   ` [patch 7/8] x86: apic - unify sync_Arb_IDs Maciej W. Rozycki
2008-08-14 20:10     ` Cyrill Gorcunov
1970-01-01  0:00 ` [patch 8/8] x86: apic - unify init_bsp_APIC Cyrill Gorcunov
2008-08-14 19:44   ` Maciej W. Rozycki
2008-08-15  6:41     ` Cyrill Gorcunov
2008-08-15 11:51       ` Ingo Molnar
2008-08-15 12:15         ` Maciej W. Rozycki
2008-08-15 13:48           ` Ingo Molnar
2008-08-15 14:45             ` Cyrill Gorcunov
2008-08-15 14:47               ` Ingo Molnar
2008-08-15 15:31               ` Maciej W. Rozycki
2008-08-15 16:35                 ` Cyrill Gorcunov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20080814184652.317090901@gmail.com \
    --to=gorcunov@gmail.com \
    --cc=hpa@zytor.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=macro@linux-mips.org \
    --cc=mingo@elte.hu \
    --cc=tglx@linutronix.de \
    --cc=yhlu.kernel@gmail.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).